# CHANGELOG


## v0.1.0 (2026-02-16)

### Build System

- Remove unused deps
  ([`c631c2a`](https://github.com/supersubscript/phenotastic/commit/c631c2a4addd53cdccfa1d6b044e86d4f2167383))

- Update everything
  ([`6b93454`](https://github.com/supersubscript/phenotastic/commit/6b934542d2b396fbcf040ec8e5d39843c9d1a46a))

### Chores

- Remove unused files
  ([`28e2fad`](https://github.com/supersubscript/phenotastic/commit/28e2fad53968e8d66af88d29ba4b7534a6b2979d))

- Update version control flags
  ([`bf66505`](https://github.com/supersubscript/phenotastic/commit/bf665059985d8ac76ff4e0ad8ba635bd6c19f4cd))

### Code Style

- Add type annotations
  ([`fe55b43`](https://github.com/supersubscript/phenotastic/commit/fe55b4333a90a95795569a7a18261accb1df07fe))

- Format
  ([`a31578f`](https://github.com/supersubscript/phenotastic/commit/a31578f838bd48e07069cedcd78cca8873e5031f))

### Features

- Add dockerfile
  ([`0690756`](https://github.com/supersubscript/phenotastic/commit/06907562153e290bcd074ec250ea832ec81fc981))

- Add makefile
  ([`caa45c3`](https://github.com/supersubscript/phenotastic/commit/caa45c393ce9746570773fd0f0bc66e1f93b8ffe))

- Add pipeline
  ([`41b57c9`](https://github.com/supersubscript/phenotastic/commit/41b57c90e304e5a57aed1d920f406909766c64ec))

- Slim down everything
  ([`056efd7`](https://github.com/supersubscript/phenotastic/commit/056efd724566674f9d0acb12386a3b3c5c3a9d60))

### Refactoring

- Improve names and simplify code
  ([`a9fc0f7`](https://github.com/supersubscript/phenotastic/commit/a9fc0f7a8b4dab6435f2e833d543c12454c51605))
